# NOMAD-CAMELS Driver for Agilent 34401A

Driver of the Agilent 34401A digital multimeter written for the measurement software [NOMAD-CAMELS](https://fau-lap.github.io/NOMAD-CAMELS/).

## Features
This driver currently supports measuring the DC and AC voltage and current, as well as resistance measurements in 2- and 4-wire configuration.  
The settable configuration is the number of PLC for a measurement.


## Documentation

For more information and documentation visit the NOMAD-CAMELS [documentation](https://fau-lap.github.io/NOMAD-CAMELS/doc/instruments/instruments.html).

## Changelog

### 0.1.2

Fixes and more functionality.

### 0.1.1

Initial upload, basic functionality.